==> 0.0.1.tar.gz: lib/src/scroller.dart <==
part of scrolling;

abstract class Scroller {
  Element element;
  num duration;
  Easing easing;

  Scroller(this.element, {this.duration: 500, this.easing: Easing.LINEAR});

  void scroll();
}

class PositionScroller extends Scroller {
  Map<String, num> _scrollProperties;
  VerticalScrollPosition _verticalScroll;
  HorizontalScrollPosition _horizontalScroll;

  PositionScroller(Element element, {VerticalScrollPosition verticalScroll, HorizontalScrollPosition horizontalScroll, num duration, Easing easing}) : super(element, duration: duration, easing: easing) {
    this._verticalScroll = verticalScroll;
    this._horizontalScroll = horizontalScroll;
  }

  VerticalScrollPosition get verticalScroll => this._verticalScroll;

  void set verticalScroll(VerticalScrollPosition verticalScroll) {
    this._verticalScroll = verticalScroll;
    _scrollProperties = null;
  }

  HorizontalScrollPosition get horizontalScroll => this._horizontalScroll;

  void set horizontalScroll(HorizontalScrollPosition horizontalScroll) {
    this._horizontalScroll = horizontalScroll;
    _scrollProperties = null;
  }

  void _configureScrollProperties() {
    _scrollProperties = {};
    if (this.horizontalScroll!= null) {
      num offset = 0;
      if (!this.horizontalScroll.aligLeft) {
        offset = this.element.offsetWidth;
      }
      _scrollProperties.putIfAbsent("scrollLeft", () => this.horizontalScroll.position + offset);
    }
    if (this.verticalScroll != null) {
      num offset = 0;
      if (!this.verticalScroll.alignTop) {
        offset = this.element.offsetHeight;
      }
      _scrollProperties.putIfAbsent("scrollTop", () => this.verticalScroll.position + offset);
    }
  }

  void scroll() {
    if (_scrollProperties == null) {
      _configureScrollProperties();
    }
    animate(this.element, duration: this.duration, easing: this.easing, properties: this._scrollProperties);
  }
}

==> 0.0.2.tar.gz: lib/src/scroller.dart <==
part of scrolling;

abstract class Scroller {
  Element element;
  num duration;
  Easing easing;

  Scroller(this.element, {this.duration: 500, this.easing: Easing.LINEAR});

  void scroll();
}

class PositionScroller extends Scroller {
  Map<String, num> _scrollProperties;
  VerticalPosition _verticalScroll;
  HorizontalPosition _horizontalScroll;

  PositionScroller(Element element, {VerticalPosition verticalScroll, HorizontalPosition horizontalScroll, num duration, Easing easing}) : super(element, duration: duration, easing: easing) {
    this._verticalScroll = verticalScroll;
    this._horizontalScroll = horizontalScroll;
  }

  VerticalPosition get verticalScroll => this._verticalScroll;

  void set verticalScroll(VerticalPosition verticalScroll) {
    this._verticalScroll = verticalScroll;
    _scrollProperties = null;
  }

  HorizontalPosition get horizontalScroll => this._horizontalScroll;

  void set horizontalScroll(HorizontalPosition horizontalScroll) {
    this._horizontalScroll = horizontalScroll;
    _scrollProperties = null;
  }

  void _configureScrollProperties() {
    _scrollProperties = {};
    if (this.horizontalScroll!= null) {
      num offset = 0;
      if (!this.horizontalScroll.aligLeft) {
        offset = this.element.offsetWidth;
      }
      _scrollProperties.putIfAbsent("scrollLeft", () => this.horizontalScroll.position + offset);
    }
    if (this.verticalScroll != null) {
      num offset = 0;
      if (!this.verticalScroll.alignTop) {
        offset = this.element.offsetHeight;
      }
      _scrollProperties.putIfAbsent("scrollTop", () => this.verticalScroll.position + offset);
    }
  }

  void scroll() {
    if (_scrollProperties == null) {
      _configureScrollProperties();
    }
    animate(this.element, duration: this.duration, easing: this.easing, properties: this._scrollProperties);
  }
}
